mocks

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 8, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockCommandable

type MockCommandable struct {
	mock.Mock
}

MockCommandable is an autogenerated mock type for the Commandable type

func NewMockCommandable

func NewMockCommandable(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockCommandable

NewMockCommandable creates a new instance of MockCommandable. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockCommandable) EXPECT

func (*MockCommandable) GetName

func (_mock *MockCommandable) GetName() string

GetName provides a mock function for the type MockCommandable

func (*MockCommandable) SetInstructions

func (_mock *MockCommandable) SetInstructions(s string)

SetInstructions provides a mock function for the type MockCommandable

func (*MockCommandable) SetName

func (_mock *MockCommandable) SetName(s string)

SetName provides a mock function for the type MockCommandable

type MockCommandable_Expecter

type MockCommandable_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockCommandable_Expecter) GetName

GetName is a helper method to define mock.On call

func (*MockCommandable_Expecter) SetInstructions

func (_e *MockCommandable_Expecter) SetInstructions(s interface{}) *MockCommandable_SetInstructions_Call

SetInstructions is a helper method to define mock.On call

  • s string

func (*MockCommandable_Expecter) SetName

func (_e *MockCommandable_Expecter) SetName(s interface{}) *MockCommandable_SetName_Call

SetName is a helper method to define mock.On call

  • s string

type MockCommandable_GetName_Call

type MockCommandable_GetName_Call struct {
	*mock.Call
}

MockCommandable_GetName_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetName'

func (*MockCommandable_GetName_Call) Return

func (*MockCommandable_GetName_Call) Run

func (*MockCommandable_GetName_Call) RunAndReturn

type MockCommandable_SetInstructions_Call

type MockCommandable_SetInstructions_Call struct {
	*mock.Call
}

MockCommandable_SetInstructions_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SetInstructions'

func (*MockCommandable_SetInstructions_Call) Return

func (*MockCommandable_SetInstructions_Call) Run

func (*MockCommandable_SetInstructions_Call) RunAndReturn

type MockCommandable_SetName_Call

type MockCommandable_SetName_Call struct {
	*mock.Call
}

MockCommandable_SetName_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SetName'

func (*MockCommandable_SetName_Call) Return

func (*MockCommandable_SetName_Call) Run

func (*MockCommandable_SetName_Call) RunAndReturn

func (_c *MockCommandable_SetName_Call) RunAndReturn(run func(s string)) *MockCommandable_SetName_Call

Jump to