install

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 8, 2026 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func LooksLikePath

func LooksLikePath(source string) bool

LooksLikePath returns true if the source appears to be a file path.

func MightBePath

func MightBePath(s string, resourceType string) bool

MightBePath returns true if the input might be a path the user forgot the --file flag for. This catches edge cases not handled by LooksLikePath, like Windows-style paths on Unix or files with common resource extensions.

Types

type Installer

type Installer struct {
	// contains filtered or unexported fields
}

Installer handles shared logic for installing resources from repositories.

func NewInstaller

func NewInstaller(t resource.ResourceType, name string, local LocalInstaller) *Installer

NewInstaller creates a new Installer for a specific resource type.

func (*Installer) InstallAllFromRepo

func (i *Installer) InstallAllFromRepo(repoName string, scope cli.Scope) error

InstallAllFromRepo installs all resources of the configured type from a specific repository.

func (*Installer) InstallFromGit

func (i *Installer) InstallFromGit(url string, scope cli.Scope) error

InstallFromGit clones a git repository and installs the resource from it.

func (*Installer) InstallFromRepo

func (i *Installer) InstallFromRepo(name string, matches []resource.Resource, scope cli.Scope) error

InstallFromRepo installs a resource from a list of matches (usually from repo lookup).

type LocalInstaller

type LocalInstaller func(sourcePath string, scope cli.Scope) error

LocalInstaller is a function that installs a resource from a local path.

Jump to