validator

package
v0.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 8, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Option

type Option func(*Validator)

Option configures a Validator.

func WithAllowEmpty

func WithAllowEmpty(allow bool) Option

WithAllowEmpty configures whether empty configs (no servers) are allowed. Default is false, meaning at least one server is required.

type Validator

type Validator struct {
	// contains filtered or unexported fields
}

Validator validates canonical MCP configurations.

func New

func New(opts ...Option) *Validator

New creates a new Validator with the given options.

func (*Validator) Validate

func (v *Validator) Validate(cfg *mcp.Config) *validator.Result

Validate checks a Config for issues. Returns a Result containing errors and warnings.

Jump to