Documentation
¶
Overview ¶
Package frontmatter provides utilities for parsing and formatting YAML frontmatter in markdown files.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrMissingFrontmatter = errors.New("missing frontmatter")
ErrMissingFrontmatter is returned by MustParse when no frontmatter is found.
Functions ¶
func Format ¶
Format formats content with YAML frontmatter. The matter struct is serialized to YAML and wrapped in "---" delimiters, followed by the body content.
func MustParse ¶
MustParse is like Parse but returns an error if no frontmatter is found. This is useful for files where frontmatter is required (skills).
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.