package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Jan 25, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package validator provides validation for agent structs.
type Agentable interface {
GetName() string
GetDescription() string
GetInstructions() string
}
Agentable is implemented by agent types that can be validated.
Issue represents a validation problem found in an agent.
Level represents the severity of a validation issue.
type Result struct {
Errors []Issue
Warnings []Issue
}
Result contains the validation results.
HasErrors returns true if there are any validation errors.
type Validator struct {
}
Validator validates agent structs.
New creates a new Validator.
When strict is true, additional warnings are generated for missing optional fields.
Validate checks an agent for compliance.
The path parameter is used for context in error messages.
Returns a Result containing errors and warnings.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.