Documentation
¶
Index ¶
- type MockCommandable
- type MockCommandable_Expecter
- type MockCommandable_GetName_Call
- type MockCommandable_SetInstructions_Call
- func (_c *MockCommandable_SetInstructions_Call) Return() *MockCommandable_SetInstructions_Call
- func (_c *MockCommandable_SetInstructions_Call) Run(run func(s string)) *MockCommandable_SetInstructions_Call
- func (_c *MockCommandable_SetInstructions_Call) RunAndReturn(run func(s string)) *MockCommandable_SetInstructions_Call
- type MockCommandable_SetName_Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockCommandable ¶
MockCommandable is an autogenerated mock type for the Commandable type
func NewMockCommandable ¶
func NewMockCommandable(t interface {
mock.TestingT
Cleanup(func())
}) *MockCommandable
NewMockCommandable creates a new instance of MockCommandable. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MockCommandable) EXPECT ¶
func (_m *MockCommandable) EXPECT() *MockCommandable_Expecter
func (*MockCommandable) GetName ¶
func (_mock *MockCommandable) GetName() string
GetName provides a mock function for the type MockCommandable
func (*MockCommandable) SetInstructions ¶
func (_mock *MockCommandable) SetInstructions(s string)
SetInstructions provides a mock function for the type MockCommandable
func (*MockCommandable) SetName ¶
func (_mock *MockCommandable) SetName(s string)
SetName provides a mock function for the type MockCommandable
type MockCommandable_Expecter ¶
type MockCommandable_Expecter struct {
// contains filtered or unexported fields
}
func (*MockCommandable_Expecter) GetName ¶
func (_e *MockCommandable_Expecter) GetName() *MockCommandable_GetName_Call
GetName is a helper method to define mock.On call
func (*MockCommandable_Expecter) SetInstructions ¶
func (_e *MockCommandable_Expecter) SetInstructions(s interface{}) *MockCommandable_SetInstructions_Call
SetInstructions is a helper method to define mock.On call
- s string
func (*MockCommandable_Expecter) SetName ¶
func (_e *MockCommandable_Expecter) SetName(s interface{}) *MockCommandable_SetName_Call
SetName is a helper method to define mock.On call
- s string
type MockCommandable_GetName_Call ¶
MockCommandable_GetName_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetName'
func (*MockCommandable_GetName_Call) Return ¶
func (_c *MockCommandable_GetName_Call) Return(s string) *MockCommandable_GetName_Call
func (*MockCommandable_GetName_Call) Run ¶
func (_c *MockCommandable_GetName_Call) Run(run func()) *MockCommandable_GetName_Call
func (*MockCommandable_GetName_Call) RunAndReturn ¶
func (_c *MockCommandable_GetName_Call) RunAndReturn(run func() string) *MockCommandable_GetName_Call
type MockCommandable_SetInstructions_Call ¶
MockCommandable_SetInstructions_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SetInstructions'
func (*MockCommandable_SetInstructions_Call) Return ¶
func (_c *MockCommandable_SetInstructions_Call) Return() *MockCommandable_SetInstructions_Call
func (*MockCommandable_SetInstructions_Call) Run ¶
func (_c *MockCommandable_SetInstructions_Call) Run(run func(s string)) *MockCommandable_SetInstructions_Call
func (*MockCommandable_SetInstructions_Call) RunAndReturn ¶
func (_c *MockCommandable_SetInstructions_Call) RunAndReturn(run func(s string)) *MockCommandable_SetInstructions_Call
type MockCommandable_SetName_Call ¶
MockCommandable_SetName_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SetName'
func (*MockCommandable_SetName_Call) Return ¶
func (_c *MockCommandable_SetName_Call) Return() *MockCommandable_SetName_Call
func (*MockCommandable_SetName_Call) Run ¶
func (_c *MockCommandable_SetName_Call) Run(run func(s string)) *MockCommandable_SetName_Call
func (*MockCommandable_SetName_Call) RunAndReturn ¶
func (_c *MockCommandable_SetName_Call) RunAndReturn(run func(s string)) *MockCommandable_SetName_Call