Discover Packages
github.com/thoreinstein/aix
internal
command
validator
package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Jan 25, 2026
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Package validator provides validation for command structs.
Issue represents a validation problem found in a command.
Level represents the severity of a validation issue.
type Result struct {
Errors []Issue
Warnings []Issue
}
Result contains the validation results.
HasErrors returns true if there are any validation errors.
Validator validates command structs.
New creates a new Validator.
Validate checks a command for compliance.
The path parameter is used for name inference if the command has no name.
Returns a Result containing errors and warnings.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.