Documentation
¶
Overview ¶
Package config provides configuration management for aix using Viper.
Index ¶
Constants ¶
const AppName = "aix"
AppName is the application name used for config file naming.
Variables ¶
This section is empty.
Functions ¶
func DefaultConfigPath ¶
func DefaultConfigPath() string
DefaultConfigPath returns the default path for the config file. This respects AIX_CONFIG_DIR if set, otherwise uses XDG config home.
Types ¶
type Config ¶
type Config struct {
Version int `mapstructure:"version" yaml:"version"`
DefaultPlatforms []string `mapstructure:"default_platforms" yaml:"default_platforms"`
Platforms map[string]PlatformOverride `mapstructure:"platforms" yaml:"platforms"`
Repos map[string]RepoConfig `mapstructure:"repos" yaml:"repos"`
}
Config represents the top-level configuration structure.
type PlatformOverride ¶
type PlatformOverride struct {
ConfigDir string `mapstructure:"config_dir" yaml:"config_dir"`
}
PlatformOverride contains configuration overrides for a specific platform.
Click to show internal directories.
Click to hide internal directories.