Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LooksLikePath ¶
LooksLikePath returns true if the source appears to be a file path.
func MightBePath ¶
MightBePath returns true if the input might be a path the user forgot the --file flag for. This catches edge cases not handled by LooksLikePath, like Windows-style paths on Unix or files with common resource extensions.
Types ¶
type Installer ¶
type Installer struct {
// contains filtered or unexported fields
}
Installer handles shared logic for installing resources from repositories.
func NewInstaller ¶
func NewInstaller(t resource.ResourceType, name string, local LocalInstaller) *Installer
NewInstaller creates a new Installer for a specific resource type.
func (*Installer) InstallAllFromRepo ¶
InstallAllFromRepo installs all resources of the configured type from a specific repository.
func (*Installer) InstallFromGit ¶
InstallFromGit clones a git repository and installs the resource from it.
Click to show internal directories.
Click to hide internal directories.